<?php

add_action( 'after_setup_theme', 'kathryn_i18n' );
/**
 * Load the child theme textdomain for internationalization.
 *
 * Must be loaded before Genesis Framework /lib/init.php is included.
 * Translations can be filed in the /languages/ directory.
 *
 * @since 1.2.0
 */
function kathryn_i18n() {
    load_child_theme_textdomain( 'kathryn', get_stylesheet_directory() . '/languages' );
}

add_action( 'wp_enqueue_scripts', 'wsm_enqueue_assets' );
/**
 * Enqueue theme assets.
 */
function wsm_enqueue_assets() {
	wp_enqueue_style( 'kathryn', get_stylesheet_uri() );
	wp_style_add_data( 'kathryn', 'rtl', 'replace' );
}

// Start the engine
require_once(TEMPLATEPATH.'/lib/init.php');

require_once( 'lib/init.php' );

// Calls the theme's constants & files
wsm_init();

// Editor Styles
add_editor_style( 'editor-style.css' );

// Create additional color style options

add_theme_support( 'genesis-style-selector',
	array(
		'kathryn-green' => __( 'Green', 'kathryn' ),
		'kathryn-blue' => __( 'Blue', 'kathryn' ),
		'kathryn-purple' => __( 'Purple', 'kathryn' ),
		'kathryn-pink' => __( 'Pink', 'kathryn' ),
		'kathryn-brown' => __( 'Brown', 'kathryn' ),
		'kathryn-mixed' => __( 'Mixed', 'kathryn' ),
	)
);


// Add Viewport meta tag for mobile browsers
add_action( 'genesis_meta', 'wsm_add_viewport_meta_tag' );
function wsm_add_viewport_meta_tag() {
    echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>';
}


/*
 * Add support for targeting individual browsers via CSS
 * See readme file located at /lib/js/css_browser_selector_readm.html
 * for a full explanation of available browser css selectors.
 */
add_action( 'get_header', 'wsm_load_scripts' );
function wsm_load_scripts() {
    wp_enqueue_script( 'browserselect', CHILD_URL . '/lib/js/css_browser_selector.js', array( 'jquery' ), '0.4.0', TRUE );
}

// Force Stupid IE to NOT use compatibility mode
add_filter( 'wp_headers', 'wsm_keep_ie_modern' );
function wsm_keep_ie_modern( $headers ) {
        if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE' ) !== false ) ) {
                $headers['X-UA-Compatible'] = 'IE=edge,chrome=1';
        }
        return $headers;
}

// Add new image sizes
add_image_size( 'Blog Thumbnail', 114, 114, TRUE );

// Modify the author box display
remove_action( 'genesis_after_entry', 'genesis_do_author_box_single', 8 );
add_action( 'genesis_before_comments', 'kathryn_author_box', 8 );
remove_action( 'genesis_before_loop', 'genesis_do_author_box_archive', 15 );
add_action( 'genesis_before_loop', 'kathryn_author_box', 8 );

function kathryn_author_box() {

	$authinfo = '';
	$authdesc = get_the_author_meta('description');

	if( !empty( $authdesc ) ) {
		$authinfo .= sprintf( '<section %s>', genesis_attr( 'author-box' ) );
		$authinfo .= get_avatar(get_the_author_meta( 'ID' ) , 90);
		$authinfo .= '<div>';
		$authinfo .= '<h3 class="author-box-title">';
		$authinfo .= __( 'About ', 'kathryn' );
		$authinfo .= '<span itemprop="name">';
		$authinfo .= get_the_author_meta( 'display_name' );
		$authinfo .= '</span>';
		$authinfo .= '</h3>';
		$authinfo .= '<p>' . get_the_author_meta('description') . '</p>';
		$authinfo .= '</div>';
		$authinfo .= '</section>';
	}
	if ( is_author() || is_single() ) {
		echo $authinfo;
	}
}

// Customize the post meta function
add_filter( 'genesis_post_meta', 'post_meta_filter' );
function post_meta_filter( $post_meta ) {
	if (is_single() ) {
    	$post_meta = '[post_categories sep=", " before="' . __( 'Categories: ', 'kathryn' ) . '"] [post_tags sep=", " before="' . __( 'Tags: ', 'kathryn' ) . '"]';
    	return $post_meta;
	}
}

// Modify Post Info
add_filter( 'genesis_post_info', 'my_post_info_filter' );
function my_post_info_filter( $post_info ) {
if ( !is_page() ) {
  $post_info = '[post_date format="m.j.y"]';
}
return $post_info;
}

// Move the post info function
remove_action( 'genesis_entry_header', 'genesis_post_info', 12 );
add_action( 'genesis_entry_header', 'genesis_post_info', 8 );


// Add Read More button to blog page and archives
add_filter( 'excerpt_more', 'wsm_add_excerpt_more' );
add_filter( 'get_the_content_more_link', 'wsm_add_excerpt_more' );
add_filter( 'the_content_more_link', 'wsm_add_excerpt_more' );
function wsm_add_excerpt_more( $more ) {
    return '<div class="more-link"><a href="' . get_permalink() . '" rel="nofollow">' . __( 'Read More', 'kathryn' ) . '</a></div>';
}


// Modify the speak your mind text/
add_filter( 'genesis_comment_form_args', 'custom_comment_form_args' );
function custom_comment_form_args( $args ) {
    $args['title_reply'] = __( 'Leave a Comment', 'kathryn' );
    return $args;
}


// Add titles to Post and Category
add_action( 'genesis_after_header', 'wsm_replace_arch_titles' );
function wsm_replace_arch_titles() {
	if ( is_category() ) {
		echo '<div class="page-title"><h3 class="entry-title">';
		$category = get_the_category('');
		echo $category[0]->cat_name;
		echo '</h3></div>';
	}

	elseif ( is_single() ) {
		echo '<div class="page-title"><h3 class="entry-title">' . __( 'Blog', 'kathryn' ) . '</h3></div>';
	}
}


// Remove page titles
add_action( 'get_header', 'wsm_remove_page_titles' );
function wsm_remove_page_titles() {
    if ( is_page() && ! is_page_template( 'page_blog.php' )   ) {
        remove_action( 'genesis_entry_header', 'genesis_do_post_title' );
	}
}

// Reposition page titles
add_action( 'genesis_after_header', 'wsm_page_heading');
function wsm_page_heading() {
	if ( is_page() ) {
		echo '<div class="page-title">';
		genesis_do_post_title();
		remove_action( 'genesis_entry_header', 'wsm_replace_arch_titles' );
		echo '</div>';
	}

}


// Remove Category Headline Title Description
remove_action( 'genesis_before_loop', 'genesis_do_taxonomy_title_description', 15 );

// Add support for Font Resizer
 add_action( 'get_header', 'wsm_font_resizer' );
function wsm_font_resizer() {
    wp_enqueue_script( 'font-resizer',CHILD_URL . '/lib/js/font-resizer.js', array('jquery'), '1.0', TRUE );
}

// Structural Wrap
add_theme_support( 'genesis-structural-wraps', array( 'header', 'nav', 'subnav', 'inner', 'footer-widgets', 'footer' ) );


// Changes Default Navigation to Primary & Footer
add_theme_support ( 'genesis-menus' ,
	array (
		'primary' => __( 'Primary Navigation Menu', 'kathryn' ),
		'footer' => __( 'Footer Navigation Menu', 'kathryn' ),
	)
);


// Remove Layouts
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );

// Setup Sidebars
unregister_sidebar('header-right');
unregister_sidebar('sidebar-alt');


genesis_register_sidebar( array(
	'id'			=> 'rotator',
	'name'			=> __( 'Rotator', 'kathryn' ),
	'description'	=> __( 'This is the image rotator section.', 'kathryn' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-cta',
	'name'			=> __( 'Home CTA Boxes', 'kathryn' ),
	'description'	=> __( 'This is the Home page CTA Boxes section.', 'kathryn' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-main-content',
	'name'			=> __( 'Home Main Content', 'kathryn' ),
	'description'	=> __( 'This is the Homepage Main Content section.', 'kathryn' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-sidebar',
	'name'			=> __( 'Home Sidebar', 'kathryn' ),
	'description'	=> __( 'This is the Homepage Sidebar.', 'kathryn' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'blog-sidebar',
	'name'			=> __( 'Blog Sidebar', 'kathryn' ),
	'description'	=> __( 'This is the Blog Page Sidebar.', 'kathryn' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'page-sidebar',
	'name'			=> __( 'Page Sidebar', 'kathryn' ),
	'description'	=> __( 'This is the Page Sidebar.', 'kathryn' ),
) );

// add first and last classes to navigation
add_filter( 'wp_nav_menu', 'wsm_add_first_and_last' );
function wsm_add_first_and_last( $output ) {
	$output = preg_replace('/class="menu-item/', 'class="first-menu-item', $output, 1);
	//$output = substr_replace( $output, 'class="last-menu-item ', strripos( $output, 'class="menu-item' ), strlen( 'class="menu-item' ) );
	return $output;
}

// CSS Style for old IE
add_action( 'wp_head','wsm_rounded_corners' );
function wsm_rounded_corners() {
		echo '<style type="text/css">';
		echo '#header .widget-area .phone, .slider, div.page-title, .home-top-left .more-link a { behavior: url(' . CHILD_URL . '/lib/js/pie/PIE.htc); }';
		echo '</style>';
}
$ch_args = array(
	'width'            => 500,
	'height'           => 80,
	'header-text'      => false,
	'flex-height'      => true,
	'flex-width'       => true,
	'header-selector'  => '.site-title',
	'wp-head-callback' => "cb_remove_image_class",
	// 'default-image' => get_stylesheet_directory_uri().'/images/logo.png',
);

if(!get_theme_mod('s9_has_title_setup')){
	if(genesis_get_option('blog_title')=="image"){
		set_theme_mod('header_image', get_stylesheet_directory_uri().'/images/logo.png');
	}
	set_theme_mod('s9_has_title_setup', true);
}

add_theme_support( 'custom-header', $ch_args );

if(!has_header_image()){
	add_filter( 'genesis_pre_get_option_blog_title', 'child_get_option_blog_title' );
};

function child_get_option_blog_title(){
	return 'text';
};

// wp-head callback
function cb_remove_image_class(){
	if(!has_header_image()){
		// remove header-image class
		add_filter('body_class', 'remove_header_image_class', 20, 2);
	}else{
		// default customizer won't work if we use cb, so we add it manual
		?>
		<style>
			.header-image .site-title{
				background-image:url(<?php echo get_header_image();?>);
			}
		</style>
		<?php
	}
}

// remove header-image body class
function remove_header_image_class($wp_classes){
	foreach($wp_classes as $key => $value){
		if ($value == 'header-image') unset($wp_classes[$key]);
	}
 
	return $wp_classes;
}
