<?php
/**
 * Kathryn Settings
 *
 * This file registers all of Kathryn's specific Theme Settings, accessible from
 * Genesis --> Kathryn Settings.
 *
 * NOTE: Change out "Kathryn" in this file with name of theme and delete this note
 */

/**
 * Registers a new admin page, providing content and corresponding menu item
 * for the Child Theme Settings page.
 *
 * @since 1.0.0
 *
 * @package kathryn
 * @subpackage WSM_Kathryn_Settings
 */
class WSM_Kathryn_Settings extends Genesis_Admin_Boxes {

	/**
	 * Create an admin menu item and settings page.
	 * @since 1.0.0
	 */
	function __construct() {

		// Specify a unique page ID.
		$page_id = 'kathryn';

		// Set it as a child to genesis, and define the menu and page titles
		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => 'genesis',
				'page_title'  => 'Kathryn Settings',
				'menu_title'  => 'Kathryn Settings',
				'capability' => 'manage_options',
			)
		);

		// Set up page options. These are optional, so only uncomment if you want to change the defaults
		$page_ops = array(
		//	'screen_icon'       => 'options-general',
		//	'save_button_text'  => 'Save Settings',
		//	'reset_button_text' => 'Reset Settings',
		//	'save_notice_text'  => 'Settings saved.',
		//	'reset_notice_text' => 'Settings reset.',
		);

		// Give it a unique settings field.
		// You'll access them from genesis_get_option( 'option_name', 'kathryn-settings' );
		$settings_field = 'kathryn-settings';

		// Set the default values
		$default_settings = array(
			'wsm_home_tagline' => '<h2>Lorem ipsum dolor sit ametconsectetur adipisicing elit</h2>',
			'wsm_home_moretext' => 'Read More',
			'wsm_home_morelink' => '',
			'wsm_copyright' => '&copy; 2014 My Name, All Rights Reserved',
			'wsm_creds' => 'Kathryn is a Premium WordPress Theme Built on Genesis',
			'wsm_contact_phone' => '123.456.7890',
			'wsm_contact_address' => '123 Streetname, Anytown, US 12345',
			'wsm_ignore_updates' => 0,
			'wsm_gforms_placeholder' => 0,
		);

		// Create the Admin Page
		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		// Initialize the Sanitization Filter
		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitization_filters' ) );

	}

	/**
	 * Set up Sanitization Filters
	 * @since 1.0.0
	 *
	 * See /lib/classes/sanitization.php for all available filters.
	 */
	function sanitization_filters() {

		genesis_add_option_filter( 'no_html', $this->settings_field,
			array(
				'wsm_home_moretext',
				'wsm_home_morelink',
			) );

	genesis_add_option_filter( 'safe_html', $this->settings_field,
			array(
				'wsm_home_tagline',
				'wsm_contact_address',
				'wsm_copyright',
				'wsm_contact_phone',
			) );


	}

	/**
	 * Set up Help Tab
	 * @since 1.0.0
	 *
	 * Genesis automatically looks for a help() function, and if provided uses it for the help tabs
	 * @link http://wpdevel.wordpress.com/2011/12/06/help-and-screen-api-changes-in-3-3/
	 */
	 function help() {
	 	$screen = get_current_screen();

		$screen->add_help_tab( array(
			'id'      => 'sample-help',
			'title'   => 'Sample Help',
			'content' => '<p>Help content goes here.</p>',
		) );
	 }

	/**
	 * Register metaboxes on Child Theme Settings page
	 * @since 1.0.0
	 */
	function metaboxes() {

		add_meta_box('wsm_header_info_metabox', 'Header Info', array( $this, 'wsm_header_info_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_home_tagline_metabox', 'Homepage Tagline', array( $this, 'wsm_home_tagline_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_footer_info_metabox', 'Footer Info', array( $this, 'wsm_footer_info_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_gforms_placeholders_metabox', __( 'Gravity Forms Auto Placeholders', 'kathryn' ), array( $this, 'wsm_gforms_placeholders_metabox' ), $this->pagehook, 'main', 'high');
		add_meta_box('wsm_upate_notifications_metabox', __( 'Update Notifications', 'kathryn' ), array( $this, 'wsm_upate_notifications_metabox' ), $this->pagehook, 'main', 'high');

	}

	/**
	 * Home Tagline Metabox
	 * @since 1.0.0
	 */
	function wsm_home_tagline_metabox() {

		echo '<p><strong>' . __( 'Tagline:', 'kathryn' ) . '</strong></p>';
		echo '<p><textarea name="' . $this->get_field_name( 'wsm_home_tagline' ) . '" cols="70" rows="3">' . esc_textarea( $this->get_field_value( 'wsm_home_tagline' ) ) . '</textarea></p>';

		echo '<p><strong>' . __( 'More Text:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_home_moretext' ) . '" id="' . $this->get_field_id( 'wsm_home_moretext' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_home_moretext' ) ) . '" size="70" /></p>';

		echo '<p><strong>' . __( 'More Link:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_home_morelink' ) . '" id="' . $this->get_field_id( 'wsm_home_morelink' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_home_morelink' ) ) . '" size="70" /></p>';

	}


	/**
	 * Footer Info Metabox
	 * @since 1.0.0
	 */
	function wsm_footer_info_metabox() {

		echo '<p><strong>' . __( 'Copyright Info:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_copyright' ) . '" id="' . $this->get_field_id( 'wsm_copyright' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_copyright' ) ) . '" size="70" /></p>';

		echo '<p><strong>' . __( 'Credits:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_creds' ) . '" id="' . $this->get_field_id( 'wsm_creds' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_creds' ) ) . '" size="70" /></p>';

	}

	/**
	 * Header Info Metabox
	 * @since 1.0.0
	 */
	function wsm_header_info_metabox() {

		echo '<p><strong>' . __( 'Phone:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_contact_phone' ) . '" id="' . $this->get_field_id( 'wsm_contact_phone' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_contact_phone' ) ) . '" size="70" /></p>';
		echo '<p><strong>' . __( 'Address:', 'kathryn' ) . '</strong></p>';
		echo '<p><input type="text" name="' . $this->get_field_name( 'wsm_contact_address' ) . '" id="' . $this->get_field_id( 'wsm_contact_address' ) . '" value="' . esc_attr( $this->get_field_value( 'wsm_contact_address' ) ) . '" size="70" /></p>';
	}

	/**
	 * Gravity Forms Auto Placeholders Metabox
	 * @since 2.0.0
	 */
	function wsm_gforms_placeholders_metabox() {

		echo '<input type="checkbox" name="' . $this->get_field_name( 'wsm_gforms_placeholder' ) . '" id="' .  $this->get_field_id( 'wsm_gforms_placeholder' ) . '" value="1"';
		checked( 1, $this->get_field_value( 'wsm_gforms_placeholder' ) ); echo '/>';

		echo '<label for="' . $this->get_field_id( 'wsm_gforms_placeholder' ) . '">' . __( 'Only convert labels to placeholders on forms or form items with the class <strong><em>gforms-placeholder</em></strong>', 'kathryn' ) . '</label>';
		echo '<p><em>' . __( 'By default, leaving this unchecked will apply the effect to all Gravity Form fields.', 'kathryn' ) . '</em></p>';

	}

	/**
	 * Update Notifications Metabox
	 * @since 2.0.0
	 */
	function wsm_upate_notifications_metabox() {

		echo '<p>' . __( 'Please check the box below if you wish to ignore/hide the theme update notification.<br/>Uncheck the box if you wish to be notified of theme updates.', 'kathryn' ) . '</p>';

		echo '<input type="checkbox" name="' . $this->get_field_name( 'wsm_ignore_updates' ) . '" id="' .  $this->get_field_id( 'wsm_ignore_updates' ) . '" value="1" ';
		checked( 1, $this->get_field_value( 'wsm_ignore_updates' ) );
		echo '/> <label for="' . $this->get_field_id( 'wsm_ignore_updates' ) . '">' . __( 'Ignore Theme Updates?', 'kathryn' ) . '</label>';

	}

}

/**
 * Add the Theme Settings Page
 * @since 1.0.0
 */
function wsm_add_kathryn_settings() {
	global $_child_theme_settings;
	$_child_theme_settings = new WSM_Kathryn_Settings;
}
add_action( 'genesis_admin_menu', 'wsm_add_kathryn_settings' );

/**
 * Add Soliloquy key
 *
 * @since 1.0.0
 */
// Soliloquy License
if ( ! get_option( 'soliloquy_license_key' ) )
	update_option( 'soliloquy_license_key', SOLILOQUY_LICENSE_KEY );
